Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Checker ¶
type Checker struct {
// contains filtered or unexported fields
}
Checker allows to check that addresses are in a trusted IPs.
func NewChecker ¶
NewChecker builds a new Checker given a list of CIDR-Strings to trusted IPs.
Click to show internal directories.
Click to hide internal directories.